@@ -6,7 +6,7 @@ use strict;
 use encoding "utf-8";
 
 # Defining the version for the Progrm.
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # Including the FileHandle module.
 use FileHandle;
@@ -75,7 +75,7 @@ Text::SenseClusters::LabelEvaluation::Driver - Module for evaluation of labels o
 		goldKeyFileName => $topicFileName,
 		goldKeyDataSource => 'wikipedia',
 		weightRatio => 10,
-		stopListFileLocation => 'stoplist.txt',
+		isClean =>1,
 	);
 
 
@@ -113,6 +113,155 @@ Note: For more usage, please refer to test-cases in "t" folder of this package.
 	and score of result.
 
 
+
+	
+	FILE FORMATS:
+
+	1. senseClusterLabelFileName:
+	---------------------------------	
+		This tells about the file that will contains the labels for the clusters generated by SenseClusters. 
+		The file format for this file should be same as that of generated  by SenseClusters.
+		
+		For e.g:
+		
+		Cluster 0 (Descriptive): George Bush, Russian President, British Prime, British Minister, India Pakistan, US George, Prime Minister, 
+		Cluster 0 (Discriminating): Russian President, British Minister, India Pakistan, US George, 
+		Cluster 1 (Descriptive): George Bush, British Prime, weapons mass, United Nations, September 11, mass destruction, United States, 
+					Prime Minister, military action
+		Cluster 1 (Discriminating): United Nations, September 11, United States
+		Cluster 2 (Descriptive): George Bush, weapons destruction, prime minister, axis evil, Saddam Hussein, weapons mass, mass destruction, 
+					Gulf War, military action, Iraqi leader
+		Cluster 2 (Discriminating): weapons destruction, prime minister, axis evil, Saddam Hussein, Gulf War, Iraqi leader
+		
+
+	2. goldKeyFileName:
+	-----------------------
+	This parameter contains the name of the file that contains the gold standard keys for the labels of clusters generated by
+	SenseClusters.
+		
+	The file format provided by user for Gold-Standard key's are dependent on the following
+	two parameters that user pass to call this module:
+	
+		1. labelComparisonMethod
+		--------------------------
+			This parameter tells that whether is passing the mapping information between
+			goldkeys and clusters or not.
+			
+			Two options available are:	1. 'direct'		- this says user will provide the mapping info.
+										 	2. 'automate' 		- this says module should find the best possible 
+										 	                    mapping between cluster's label and goldkeys.	
+			 
+		2. goldKeyDataSource  
+		-------------------------
+	  		This parameter tell this module from where it can read more information about
+	  		the goldkeys
+	  		
+			Options for this parameter are:		1. 'wikipedia'		- this tells to fetch data from wikipedia.
+									 				2. 'wordnet'		- this tells to fetch data from wordnet.
+									 				3. 'userData'		- this tells user will give the data along 
+									 				                    with mapping.
+									 				
+		
+	
+	Combinatios of the various values for the aboue two parameters will give the following six cases:	
+
+		(Please note that separator between cluster name and Goldkeys are ":::".
+		Also, the separator between Goldkeys and their data are ":::")  
+		
+	Case 1.		labelComparisonMethod => 'direct', 			goldKeyDataSource => 'userData' 
+		
+
+		a) In this case user should provide the mapping between the clusters and Goldkeys
+		b) User should also provide the data about these goldstandard keys.
+		
+				for e.g: 
+						
+				Cluster0:::Tony Blair  
+				Cluster1:::Vladimir Putin 
+				Cluster2:::Saddam Hussein
+
+				Tony Blair::: Anthony Charles Lynton Blair (born 6 May 1953)[1] is a British Labour Party politician who served 
+				as the Prime Minister of the United Kingdom from 1997 to 2007. He was the Member of Parliament (MP) for Sedgefield 
+				from 1983 to 2007 and Leader of the Labour Party from 1994 to 2007. He resigned from all of these positions in 
+				June 2007.
+				
+				Vladimir Putin::: Vladimir Vladimirovich Putin (Russian: ( listen); born 7 October 1952) is a Russian politician  
+				who has been the President of Russia since 7 May 2012. Putin previously served as President from 2000 to 2008, and  
+				as Prime Minister of Russia from 1999 to 2000 and again from 2008 to 2012. Putin was also previously the Chairman  
+				of United Russia.
+				
+				Saddam Hussein::: Saddam Hussein Abd al-Majid al-Tikriti  28 April 1937[2] – 30 December 2006)[3] was the fifth 
+				President of Iraq, serving in this capacity from 16 July 1979 until 9 April 2003.[4][5] A leading member of the 
+				revolutionary Arab Socialist Ba'ath Party.
+
+	Case 2.		labelComparisonMethod => 'direct', 			goldKeyDataSource => 'wikipedia'
+		
+		a) In this case user just need to provide the mapping between the clusters and Goldkeys.
+		b) User do not need to provide the data about these goldstandard keys. Even though, if user provides the
+		   data about these topics, it will be ignored.
+		
+		
+				 for e.g: 
+					Cluster0:::Tony Blair  
+					Cluster1:::Vladimir Putin 
+					Cluster2:::Saddam Hussein
+		
+					
+	Case 3. 	labelComparisonMethod => 'direct', 			goldKeyDataSource => 'wordnet'
+
+		a) In this case also user just need to provide the mapping between the clusters and Goldkeys.
+		b) User do not need to provide the data about these goldstandard keys. 
+		
+				for e.g:
+					Cluster0:::Tony Blair  
+					Cluster1:::Vladimir Putin 
+					Cluster2:::Saddam Hussein
+		
+		
+	Case 4. 	labelComparisonMethod => 'automate', 			goldKeyDataSource => 'userData'
+		
+			a) No Mapping between the clusters and Goldkeys.
+			b) User will just need to provide the data about these goldstandard keys. 
+			   
+			   
+				for e.g: 
+				Tony Blair::: Anthony Charles Lynton Blair (born 6 May 1953)[1] is a British Labour Party politician who served 
+				as the Prime Minister of the United Kingdom from 1997 to 2007. He was the Member of Parliament (MP) for Sedgefield 
+				from 1983 to 2007 and Leader of the Labour Party from 1994 to 2007. He resigned from all of these positions in 
+				June 2007.
+				
+				Vladimir Putin::: Vladimir Vladimirovich Putin (Russian: ( listen); born 7 October 1952) is a Russian politician  
+				who has been the President of Russia since 7 May 2012. Putin previously served as President from 2000 to 2008, and  
+				as Prime Minister of Russia from 1999 to 2000 and again from 2008 to 2012. Putin was also previously the Chairman  
+				of United Russia.
+				
+				Saddam Hussein::: Saddam Hussein Abd al-Majid al-Tikriti  28 April 1937[2] – 30 December 2006)[3] was the fifth 
+				President of Iraq, serving in this capacity from 16 July 1979 until 9 April 2003.[4][5] A leading member of the 
+				revolutionary Arab Socialist Ba'ath Party.
+		
+		
+	Case 5.		labelComparisonMethod => 'automate', 			goldKeyDataSource => 'wikipedia'
+	
+				a) No Mapping between the clusters and Goldkeys.
+				b) User will just need to provide the comma separated goldstandard keys. 
+					
+				for e.g: 
+					Tony Blair , Vladimir Putin, Saddam Hussein
+				
+				
+				
+	Case 6.		labelComparisonMethod => 'automate', 			goldKeyDataSource => 'wordnet'
+
+				a) No Mapping between the clusters and Goldkeys.
+				b) User will just need to provide the comma separated goldstandard keys. 
+
+					
+				for e.g: 
+					Tony Blair , Vladimir Putin, Saddam Hussein
+
+
+		Sample files for all the cases are included in test-section of the modules. 
+		
 =head1 RESULT:
 
    a) Contingency Matrix:	
@@ -188,7 +337,7 @@ The 'optionHash' has the following elements:
 		A) 'DirectAssignment' and 
 		B) 'AutomateAssignment'.
  
-   This is mandatory parameter.
+This is mandatory parameter.
 
 3. goldKeyFile:      
 	Name of the file containing the actual topics (keys) and their data for the 
@@ -206,15 +355,26 @@ The 'optionHash' has the following elements:
 		2. 'User' 
 		3. 'Wordnet' (Will be supported in future).
 		
-	This is the mandatory parameter.
+This is the mandatory parameter.
 	
 6. weightRatio:       
 	This ratio tells us about the weightage we should provide to Discriminating 
 	label over the descriptive label. Default value is set to 10.
 	
 7. stopList:             
-	This is the name of file which contains the list of all stop words. 
-
+	This is the name of file which contains the list of all stop words. This is the 
+	optional parameter and its formating should match the requirement of the Text::
+	Simialrity i.e. a single stop word in a single line.
+	for e.g: 
+	
+	Content of stoplist.txt should look like:
+			the
+			of
+			in
+			:
+			:
+			to
+	
 8. isClean:              
 	This variable will decide whether to keep or delete temporary files.Default 
 	value is 'true'.
@@ -244,6 +404,7 @@ The 'optionHash' has the following elements:
 Examples 
 
 1. With minimum parameters:
+
 		%inputOptions = (
 			senseClusterLabelFileName => 'labelFile.txt', 
 			labelComparisonMethod => 'DirectAssignment',
@@ -251,7 +412,7 @@ Examples
 			goldKeyDataSource => 'UserData'
 		);
 	
-		The above mentioned four parameters are mandatory.
+The above mentioned four mandatory parameters.
 		
 2. For Help:
 
@@ -260,6 +421,7 @@ Examples
 		);
 		
 3. With all parameters:
+
 	%inputOptions = (
 		senseClusterLabelFileName => 'labelFile.txt', 
 		labelComparisonMethod => 'AutomateAssignment',
@@ -268,7 +430,7 @@ Examples
 		goldKeyDataSource => 'Wikipedia',
 		weightRatio => 10,
 		stopListFileLocation => 'stoplist.txt',
-		isClean => 0,
+		isClean => 1,
 		verbose => 1,
 		help => 0
 	);
@@ -309,6 +471,8 @@ our $labelType_Discriminating = "discriminating";
 our $helpExitCode = 400;
 our $requiredErrorExitCode   = 404;
 our $unknownErrorExitCode  = 502;
+our $missingMappingErrorExitCode  = 401;
+our $missingKeyDataErrorExitCode  = 402;
 
 
 # Defining the file handle for the output file.
@@ -494,11 +658,48 @@ sub error{
 	my $errorCode = shift;
 	my $errorMessage = shift;
 		
-	print "Program exiting with the error. ";
-	print "\nError Code=$errorCode. $errorMessage \n\n";
+	print STDERR "Program exiting with the error. ";
+	print STDERR "\nError Code=$errorCode. \n\t$errorMessage \n\n";
 }
 
 
+
+# Method for generating the error for "missing mapping".    
+sub errorMissingMapping{
+	# Getting the object from the argument.
+	my $driverObject = shift;
+		
+	# Raise Error: Missing Cluster's label and GoldStandard Key mapping.
+	$driverObject->{$errorCode} = $missingMappingErrorExitCode; 
+	$driverObject->{$errorMessage}= "Missing the mapping between Clusters and GoldStandard Keys.". 
+		"\n\tPlease specify the mapping in File containing information about GoldStandard Keys!".
+		"\n\tRefer this module cpan documentation about, \"how to specify the mapping\"!";
+	
+	# Calling method for printing the error message.	
+	error($driverObject->{$errorCode}, $driverObject->{$errorMessage});
+	
+	exit $driverObject->{$errorCode};
+}
+
+
+# Method for generating the error for "missing user data in the GoldKeyFile".    
+sub errorMissingUserData{
+
+	# Getting the object from the argument.
+	my $driverObject = shift;
+	
+	# Raise Error: Missing user data for the GoldStandard Key.
+	$driverObject->{$errorCode} = $missingKeyDataErrorExitCode; 
+	$driverObject->{$errorMessage}= "Missing the data for GoldStandard Keys.". 
+		"\n\tPlease specify the data for the GoldStandard Keys!".
+		"\n\tRefer this module cpan documentation about, \"how to specify the data for the gold stadndard key\"!";
+	error($driverObject->{$errorCode}, $driverObject->{$errorMessage});
+	
+	exit $driverObject->{$errorCode};
+}
+
+
+
 ########################################################################################
 =head1 Function: evaluateLabels
 
@@ -542,9 +743,9 @@ function will call the other modules for completing the process.
 						 contingency matrix.
 				Step 7: Overall Accuracy for the current cluster's label assignment can be calculated as : 		 		  
 				
-						 							Sum (Diagonal Scores)
-					  		Accuracy =	 -------------------------------------------
-					 						Sum (All the Scores of contingency table)
+						 				  Sum (Diagonal Scores)
+					  		Accuracy =  -------------------------------------------
+					 					  Sum (All the Scores of contingency table)
 					 						
 		Case B: User has not provided the mapping information about the cluster and gold standard key.
 			  	 We will use the Hungarian algorithm to compute the mapping.
@@ -571,9 +772,9 @@ function will call the other modules for completing the process.
 				Step 6: Use the above mapping to calculate the total diagonal score for the new contingency matrix. 
 				Step 7: Overall Accuracy for the current cluster's label assignment can be calculated as : 		 		  
 				
-						 							Sum (Diagonal Scores)
+						 				  Sum (Diagonal Scores)
 					  		Accuracy =	 -------------------------------------------
-					 						Sum (All the Scores of contingency table)
+					 					  Sum (All the Scores of contingency table)
 
 =cut
 
@@ -588,6 +789,12 @@ sub evaluateLabels{
 	# Getting the clusters file name, from the $driverObject.
 	my $clusterFileName = $driverObject->{$senseClusterLabelFileName};
 
+	# Getting the "isClean" parameter from the class variable. 
+	my $isCleaned = $driverObject->{$isClean};
+	
+	# Getting the "verbose" option from the class variable.
+	my $verboseOption = $driverObject->{$verbose};
+	
 	# Creating the read-file object for reading the cluster's label.
 	my $readClusterFileObject = 
 			Text::SenseClusters::LabelEvaluation::ReadingFilesData->new ($clusterFileName);
@@ -620,6 +827,13 @@ sub evaluateLabels{
 			my %mappingHash = %$hashRef;
 			my @topicArray = @$topicArrayRef;
 			
+			
+			# If there is no mapping, then generate error here..... 
+			if(!%mappingHash){
+				errorMissingMapping($driverObject);
+			}
+			
+			
 		# Subcase1: User provides data for gold standard keys.			
 		if(lc($driverObject->{$goldKeyDataSource}) eq $standardReferenceName_UserData){
 			
@@ -631,11 +845,18 @@ sub evaluateLabels{
 			
 			# Reading the hash from its reference.
 			my %topicDataHash = %$topicDataHashRef;
+
+			# If there is no user's data for the topics, generate error here..... 
+			if(!%topicDataHash){
+				errorMissingUserData($driverObject);
+			}
+			
+
 			
 			# Calling the function 'makeContigencyMatrix' to get the contingency matrix of similarity-scores.
 			my ($matrixScoreRef, $colHeaderRef, $rowHeaderRef, $totalMatrixScore) = 
 				makeContigencyMatrix(\%labelSenseClustersHash, \%topicDataHash, $driverObject->{$weightRatio}, 
-					$driverObject->{$stopListFileLocation});
+					$driverObject->{$stopListFileLocation}, $verboseOption);
 				
 			# Calling the function 'printMatrix' to print the contingency matrix.	
 			Text::SenseClusters::LabelEvaluation::AssigningLabelUsingHungarianAlgo::printMatrix 
@@ -658,7 +879,7 @@ sub evaluateLabels{
 				# Call wikipedia function.
 				my $topicData = 
 					Text::SenseClusters::LabelEvaluation::Wikipedia::GetWikiData::getWikiDataForTopic(
-							$topic);
+							$topic, $isCleaned);
 				$topicDataHash{$topic} = $topicData;
 				#print "$topic $topicData\n";
 			}
@@ -666,8 +887,8 @@ sub evaluateLabels{
 			# Calling the function 'makeContigencyMatrix' to get the contingency matrix of similarity-scores.
 			my ($matrixScoreRef, $colHeaderRef, $rowHeaderRef, $totalMatrixScore) = 
 				makeContigencyMatrix(\%labelSenseClustersHash, \%topicDataHash, $driverObject->{$weightRatio},
-					$driverObject->{$stopListFileLocation});
-			print "\nContigency Matrix based on user input::\n";
+					$driverObject->{$stopListFileLocation}, $verboseOption);
+			print STDERR "\nContigency Matrix based on user input::\n";
 			
 			# Calling the function 'printMatrix' to print the contingency matrix.
 			Text::SenseClusters::LabelEvaluation::AssigningLabelUsingHungarianAlgo::printMatrix 
@@ -701,10 +922,15 @@ sub evaluateLabels{
 			# Reading the hash from its reference.
 			my %topicDataHash = %$topicDataHashRef;
 			
+			# If there is no user's data for the topics, generate error here..... 
+			if(!%topicDataHash){
+				errorMissingUserData($driverObject);
+			}
+			
 			# Calling the function which will create the contingency matrix for given set of inputs.
 			my ($matrixScoreRef, $colHeaderRef, $rowHeaderRef,$totalMatrixScore) = 
 				makeContigencyMatrix(\%labelSenseClustersHash, \%topicDataHash, $driverObject->{$weightRatio},
-					$driverObject->{$stopListFileLocation});
+					$driverObject->{$stopListFileLocation}, $verboseOption);
 			
 			# Reading the array from its referece.	
 			my @matrixScore = @$matrixScoreRef;
@@ -712,16 +938,22 @@ sub evaluateLabels{
 			my @rowHeader = @$rowHeaderRef;
 			
 			# Creating the Hungarian object.
-			my $hungrainObject = Text::SenseClusters::LabelEvaluation::AssigningLabelUsingHungarianAlgo
+			my $hungarainObject = Text::SenseClusters::LabelEvaluation::AssigningLabelUsingHungarianAlgo
 						->new(\@matrixScore, \@colHeader, \@rowHeader);
 						
 			# Reading the Mapping with help of function.
-			my ($accuracy,$finalMatrixRef,$newColumnHeaderRef) = $hungrainObject->reAssigningWithHungarianAlgo();
+			my ($accuracy,$finalMatrixRef,$newColumnHeaderRef) = $hungarainObject->reAssigningWithHungarianAlgo();
+			
 			
 			# Rounding off accuracy to decimal place.				
 			$accuracyScore = sprintf("%.2f", ($accuracy*100));
-			print "\n\nAccuracy of labels is $accuracyScore\% \n\n";
+			print STDERR "\n\nAccuracy of labels is $accuracyScore\% \n\n";
 
+			if($accuracy == 0){
+				print STDERR "\n\n Accuracy score \"zero\" indicates either of the following two facts::\n";
+				print STDERR " 1. Labels assigned to Cluster is completely wronged.    OR\n";
+				print STDERR " 2. Gold-Keys provided by you are not correct.... \n";
+			}
 
 		# Subcase2: User provides the gold standard keys. We will fetch data from Wikipedia.
 		# 			User will just provide the data about the topics, but no mapping.
@@ -739,18 +971,16 @@ sub evaluateLabels{
 			foreach my $topic (@topicArray){
 				# Call wikipedia function.
 				my $topicData = 
-					Text::SenseClusters::LabelEvaluation::Wikipedia::GetWikiData::getWikiDataForTopic($topic);
+					Text::SenseClusters::LabelEvaluation::Wikipedia::GetWikiData::getWikiDataForTopic($topic, $isCleaned);
 				
 				# Setting the data about the topic into hash.	
 				$topicDataHash{$topic} = $topicData;
-				
-				# TODO:: Create the file for the data, if user has kept isClean=0.
 			}
 			
 			# Calling the function which will create the contingency matrix for given set of inputs.			
 			my ($matrixScoreRef, $colHeaderRef, $rowHeaderRef, $totalMatrixScore) = 
 				makeContigencyMatrix(\%labelSenseClustersHash, \%topicDataHash, $driverObject->{$weightRatio}, 
-					$driverObject->{$stopListFileLocation});
+					$driverObject->{$stopListFileLocation}, $verboseOption);
 			
 			# Reading the array from its referece.	
 			my @matrixScore = @$matrixScoreRef;
@@ -758,15 +988,15 @@ sub evaluateLabels{
 			my @rowHeader = @$rowHeaderRef;
 			
 			# Creating the object of the class AssigningLabelUsingHungarianAlgo.
-			my $hungrainObject = Text::SenseClusters::LabelEvaluation::AssigningLabelUsingHungarianAlgo
+			my $hungarainObject = Text::SenseClusters::LabelEvaluation::AssigningLabelUsingHungarianAlgo
 						->new(\@matrixScore, \@colHeader, \@rowHeader);
 						
 			# Reading the Mapping with help of function.
-			my ($accuracy,$finalMatrixRef,$newColumnHeaderRef) = $hungrainObject->reAssigningWithHungarianAlgo();
+			my ($accuracy,$finalMatrixRef,$newColumnHeaderRef) = $hungarainObject->reAssigningWithHungarianAlgo();
 			
 			# Rounding off accuracy to decimal place.				
 			$accuracyScore = sprintf("%.2f", ($accuracy*100));
-			print "\n\nAccuracy of labels is $accuracyScore\% \n\n";
+			print STDERR "\n\nAccuracy of labels is $accuracyScore\% \n\n";
 			
 		}elsif (lc($driverObject->{$goldKeyDataSource}) eq $standardReferenceName_WordNet){
 			
@@ -782,7 +1012,7 @@ sub evaluateLabels{
 }
 
 ##########################################################################################
-=head1 function: makeContigencyMatrix
+=head1 Function: makeContigencyMatrix
 
 This method is responsible for making the Contigency Matrix containing the similarity-scores of the labels with the data of the gold standard keys.
 	 
@@ -797,6 +1027,7 @@ This method is responsible for making the Contigency Matrix containing the simil
 				
 				
 @description	:
+
 	1). It will iterate through the hash (%labelSenseClustersHash) and extracts the descriptive and discriminating labels for each clusters.
 	2). It will read the data about each gold standard key from the hash (%topicDataHash).
 	3). It then uses the module, Text::SenseClusters::LabelEvaluation::SimilarityScore to get various similarity score.
@@ -822,6 +1053,9 @@ sub makeContigencyMatrix{
 	# Getting the stop list file location. 
 	my $stopListFileLoc = shift;
 	
+	# Getting the verbose option. 
+	my $verboseOpt = shift;
+	
 	# Defining the matrix which contains the score.
 	my @matrixScore = ();
 	# Defining the internal Index for the matrix score.
@@ -859,7 +1093,9 @@ sub makeContigencyMatrix{
 			# Descriptive labels and Gold Key Data.
 			my $similarityObject = Text::SenseClusters::LabelEvaluation::SimilarityScore
 					->new($clusterDescriptiveLabel,$topicDataHash{$topicKey}, 
-							$stopListFileLoc);
+							$stopListFileLoc,$verboseOpt );
+							
+			# Calling the SimilarityScore module to get the overlapping score.	
 			my ($score, %allScores) = $similarityObject->computeOverlappingScores();
 			my $descriptiveScore = $allScores{'raw_lesk'};			
 
@@ -867,7 +1103,9 @@ sub makeContigencyMatrix{
 			# Discriminating labels and Gold Key Data.
 			$similarityObject = Text::SenseClusters::LabelEvaluation::SimilarityScore
 					->new($clusterDiscriminatingLabel,$topicDataHash{$topicKey}, 
-							$stopListFileLoc);
+							$stopListFileLoc, $verboseOpt);
+			
+			# Calling the SimilarityScore module to get the overlapping score.				
 			($score, %allScores) = $similarityObject->computeOverlappingScores();
 			my $discriminatingScore = $allScores{'raw_lesk'};
 
@@ -893,22 +1131,23 @@ sub makeContigencyMatrix{
 Method used for calculating the Accuracy score for the labels generated by the
 SenseClusters or others.
 
-@argument1		: $mappingHashRef (Reference to Hash which contains the mapping information about the cluster and gold standard) 
-@argument2		: $matrixScoreRef (2-D Array/Matrix which contains the similarity-scores of each labels)
-@argument3		: $colHeaderRef (Reference of array which contains the column header)
+@argument1		: $mappingHashRef (Reference to Hash which contains the mapping information about the cluster and gold standard) \\
+@argument2		: $matrixScoreRef (2-D Array/Matrix which contains the similarity-scores of each labels) \\
+@argument3		: $colHeaderRef (Reference of array which contains the column header) \\
 @argument4		: $rowHeaderRef (Reference of array which contains the row header)
 @argument5		: $totalMatrixScore (Total similarity score of the labels with gold standard)
  
 @return 		: Return the overall accuracy of the labels assigned by the SenseClusters.
 		  
 @description	:
+
 		1). With the help of ()$mappingHashRef $matrixScoreRef $colHeaderRef $rowHeaderRef),
 		    this function try to calculate the sum of all diagonal elements.
 		2).  It will then calculate the accuracy for the assignment as
 	
-			 					Sum (Diagonal Scores)
+			 				 Sum (Diagonal Scores)
 		  		Accuracy =	 -------------------------
-		 						Sum (All the Scores)
+		 					 Sum (All the Scores)
 		 						
 =cut
 
@@ -932,30 +1171,41 @@ sub calculateAccuracy{
 	# Variable which will hold TotalMatrixScore.
 	my $diagonalScore = 0;
 	
-	print "\n\n Mapping provided by user\n";
+	print STDERR "\n\n Mapping provided by user\n";
 	for my $key (keys %mappingHash){
 		my $rowIndex = 0;
 		my $colIndex = 0;
 		
-		#print "$key $mappingHash{$key} @rowHeader @colHeader \n";
-		for my $index(0..@rowHeader){
+		#print STDERR "\n$key $mappingHash{$key} \t @rowHeader \t @colHeader \n\n\n";
+		for my $index(0..@rowHeader-1){
 			if($key eq $rowHeader[$index]){
 				$rowIndex = $index;
 			}
 		}
-		for my $index(0..@colHeader){
+		for my $index(0..@colHeader-1){
 			if($mappingHash{$key} eq $colHeader[$index]){
 				$colIndex = $index;
 			}
 		}
 		# Getting the diagonal.
 		$diagonalScore = $diagonalScore +  $matrixScore[$rowIndex][$colIndex];
-		print "\t$key\t<-->\t$mappingHash{$key} \n";
+		print STDERR "\t$key\t<-->\t$mappingHash{$key} \n";
 	}
 
-	# Making the accuracy in percentage and rounding off it to 2 decimal place.	
-	my $accuracy = sprintf("%.2f", ($diagonalScore *100 /$totalMatrixScore));
-	print "\nAccuracy of assigned labels =". $accuracy ."\%\n";
+	# Defining the accuracy.
+	my $accuracy = 0;
+	
+	if($totalMatrixScore == 0){
+		$accuracy = 0;
+	}else{
+		# Making the accuracy in percentage and rounding off it to 2 decimal place.	
+	 	$accuracy = sprintf("%.2f", ($diagonalScore *100 /$totalMatrixScore));
+	}
+	
+	print STDERR "\nAccuracy of assigned labels =". $accuracy ."\%\n\n\n";
+	
+	# Returning the accuracy.
+	return $accuracy;
 }
 
 
@@ -976,7 +1226,7 @@ sub calculateAccuracy{
 http://senseclusters.cvs.sourceforge.net/viewvc/senseclusters/LabelEvaluation/ 
  
 Last modified by :
-$Id: Driver.pm,v 1.2 2013/02/14 03:50:08 jhaxx030 Exp $
+$Id: Driver.pm,v 1.3 2013/03/07 23:22:22 jhaxx030 Exp $
 
 =head1 AUTHORS
 
@@ -1014,4 +1264,4 @@ along with this program; if not, write to:
 =cut
 #######################################################################################################
 
-1;
\ No newline at end of file
+1;
